/*
 * File   : platten.h
 * Purpose: This file contains all global definations used by more than
 *          one program file.
 * Autor  : Andreas Theofilu
 *
 * Copyright (C) 1998, 1999 by Theos Soft.
 */

/* 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

/*
 * Common function prototypes
 *
 * Modul: init.esql
 */
void init ();
void CloseDatabase ();
int CheckSqlError ();
void DisplaySqlError (Widget w);
char *GetCompoundString (XmString cstr, char *ret, int retlen);
char *IDateToChar (long idate, char *sdate);
long CharToIDate (Widget w, char *date);
char *ltrim (char *buf);
char *rtrim (char *buf);
int ReadLine (int fd, char *buf, int len);
Bool GetOptions (Widget w);
char *Interpoint (double Zahl, int prec, char *ret, int Money);
char *StripNum (char *str);
#ifdef HAVE_PSQL
char *ECPGquote (char *str, int max);
#endif
int WriteOptions ();
void GetHelp (Widget w, String section);

/*
 * Modul: platten.c
 */
void CheckDateCallback (Widget w, XtPointer client_data, XtPointer call_data);
void CheckNumericCallback (Widget w, XtPointer client_data, XtPointer call_data);
void StripNumericCallback (Widget w, XtPointer client_data, XtPointer call_data);
void PointNumericCallback (Widget w, XtPointer client_data, XtPointer call_data);
int CheckDate (Widget w, char *date);
Boolean GetResourcePath (char *name);

/*
 * Modul: single.esql
 */
void NewSingle ();
void SearchSingle ();
void AddNewSingleCallback (Widget w, XtPointer client_data, XtPointer call_data);
void ClearValuesCallback (Widget w, XtPointer client_data, XtPointer call_data);
void FirstSingleFillCallback (Widget dialog, Widget list);
void addSingleDisableButtonsCallback (Widget add, Widget new);
void QuerySingleCallback (Widget w, XtPointer client_data, XtPointer call_data);
void siPartChooserCallback (Widget w, XtPointer tag, XtPointer data);
void SingleSearchTypeCallback (Widget w, XtPointer tag, XtPointer data);
void OkaySingleCallback (Widget w, XtPointer client_data, XtPointer call_data);
void UpdateSingleCallback (Widget w, XtPointer client_data, XtPointer call_data);
void siEnterCellCallback (Widget w, XtPointer client_data, XtPointer call_data);

/*
 * Modul: wunsch.esql
 */
void ListWish ();
void FirstWunschFillCallback (Widget dialog, Widget list);
void QueryWunschCallback (Widget w, XtPointer client_data, XtPointer call_data);
void wuPartChooserCallback (Widget w, XtPointer tag, XtPointer data);
void WunschSearchTypeCallback (Widget w, XtPointer tag, XtPointer data);
void NewWish ();
void wuEnterCellCallback (Widget w, XtPointer client_data, XtPointer call_data);
void AddNewWunschCallback (Widget w, XtPointer tag, XtPointer data);
void UpdateWunschCallback (Widget w, XtPointer client_data, XtPointer call_data);
void DeleteWunschCallback (Widget w, XtPointer tag, XtPointer data);

/*
 * Modul: lpsAdd.esql
 */
void NewLP ();
void NewLPCut ();
void NewLPCutDialog ();
void AddLpLabelCallback (Widget w, XtPointer tag, XtPointer data);
void AddLpCutsCallback (Widget w, XtPointer tag, XtPointer data);
void GetCDDBCallback (Widget w, XtPointer tag, XtPointer data);
void rccClearValuesCallback (Widget w, XtPointer tag, XtPointer data);

/*
 * Modul: lpsUpd.esql
 */
void UpdateLpCallback (Widget w, XtPointer tag, XtPointer data);
void UpdateKennChangedCallback (Widget w, XtPointer tag, XtPointer data);
void UpdrclInitDiscid (Widget w);
void rclInitChooser (Widget wk, Widget wd);
void rclAutoCallback ();
void rclClearValuesCallback (Widget w, XtPointer tag, XtPointer data);

/*
 * Modul: lps.esql
 */
void SearchLps ();
void FirstFillCallback (Widget dialog, Widget list);
void LPSearchValueChangedCallback (Widget w, XtPointer client_data, XtPointer call_data);
void MasterListCallback (Widget w, XtPointer tag, XtPointer data);
void lpsPartChooserCallback (Widget w, XtPointer tag, XtPointer data);
void lpsSearchTypeCallback (Widget w, XtPointer tag, XtPointer data);
void lpsEnterCellCallback (Widget w, XtPointer tag, XtPointer data);
void lpsCutMasterCallback (Widget w, XtPointer tag, XtPointer data);
void NewKennChangedCallback (Widget w, XtPointer tag, XtPointer data);
void PutCDDBCallback (Widget w, XtPointer tag, XtPointer data);
void SubmitCDDBCallback (Widget w, XtPointer tag, XtPointer data);
int CountCuts (Widget w, long num);

/*
 * Modul: print.esql
 */
void PrintSingles ();
void prAllValueChangedCallback (Widget w, XtPointer tag, XtPointer data);
void prtSearchVerifyCallback (Widget w, XtPointer tag, XtPointer data);
void StopPrintCallback (Widget w, XtPointer client_data, XtPointer call_data);

/*
 * Modul: printLps.esql
 */
void PrintLps ();
void prAllLpsValueChangedCallback (Widget w, XtPointer tag, XtPointer data);
void prtSearchLpsVerifyCallback (Widget w, XtPointer tag, XtPointer data);

/*
 * Modul: printWunsch.esql
 */
void PrintWish ();
void prAllWishValueChangedCallback (Widget w, XtPointer tag, XtPointer data);
void prtSearchWishVerifyCallback (Widget w, XtPointer tag, XtPointer data);

/*
 * Modul: options.c
 */
void Options ();
void OptionChooserChangedCallback (Widget w, XtPointer tag, XtPointer data);
void OptionDialogInit (Widget w);

/*
 * Modul: opCDDB.c
 */
void OpCDDB ();
void opRemoteChooserCallback (Widget w, XtPointer tag, XtPointer data);
void opProxyChooserCallback (Widget w, XtPointer tag, XtPointer data);
void AddCDDBServer (Widget w, XtPointer tag, XtPointer data);
void opLbServerCallback (Widget w, XtPointer tag, XtPointer data);
void opLbMailCallback (Widget w, XtPointer tag, XtPointer data);
void DeleteCDDBServer (Widget w, XtPointer tag, XtPointer data);
void AddEMAILDestination (Widget w, XtPointer tag, XtPointer data);
void DeleteEMAILDestination (Widget w, XtPointer tag, XtPointer data);

/*
 * Global variables
 */
extern Widget toplevel;
extern int has_trans;

/*
 * Global structures for resources.
 */
typedef struct {
	String Database;
	String Version;
	String datePattern;
	String CDDBPath;
	String cdrom;
	String cdmount;
	String helpCmd;
	int iCurrDigits;
	int iCurrency;
	int iNegCurr;
	String sCurrency;
	String sDecimal;
	String sThousand;
} application_resource_t;

typedef struct
{
	int chPrinter;
	char ipPrinter[51];
	char ipFile[51];
	char ipTrenn[2];
	char ipDatef[11];
	char ipCDDBPath[256];
	char ipMailCmd[128];
} option_t;

struct MAIL
{
	char mail[128];
	struct MAIL *next;
};

extern application_resource_t app_resources;
extern option_t option;
extern struct MAIL *firstMail;

